Mid-2019: April 2019 local authority district codes edition of this dataset,
this is UK wide and covers country, regions and LTLA (2019 boundaries)
uk_population_2019_by_10yr_age dataframe with 3980 rows and 6 columns
-
name (chr)
The region name
code (chr)
The region code
codeType (chr)
The ONS geographical region code type (including year)
class (chr)
The age group in 10 year age bands
population (dbl)
the count of the population in that age group
baseline_proportion (dbl)
the proportion of the total regional population that is in an age group