ons_infection_survey: ONS COVID-19 infection survey
Description
The COVID-19 ONS infection survey took a random sample of the population
and provides an estimate of the prevalence of COVID-19 that is theoretically
free from ascertainment bias. This data set is the output of the model based
on underlying data.
Usage
data("ons_infection_survey")
Arguments
Format
An object of class grouped_df (inherits from tbl_df, tbl, data.frame) with 9820 rows and 8 columns.
Details
code (chr)
The ONS geographical region code
codeType (chr)
The type of ONS geographical code
name (chr)
The ONS geographical region name
date (date)
A date
prevalence.0.5 (dbl)
the median proportion of people in the region testing positive for
COVID-19
prevalence.0.025 (dbl)
the lower CI of the proportion of people in the region testing
positive for COVID-19
prevalence.0.975 (dbl)
the upper CI of the proportion of people in the region testing positive
for COVID-19
denom (int)
the sample size on which this estimate was made (daily rate inferred
from weekly sample sizes.)